@@ -30,73 +30,74 @@
 namespace reSIDfp
 {
 
-class Integrator;
-
 /**
  * SID filter base class
  */
 class Filter
 {
 private:
-    FilterModelConfig* fmc;
-
     unsigned short** mixer;
     unsigned short** summer;
     unsigned short** resonance;
     unsigned short** volume;
 
 protected:
-    /// VCR + associated capacitor connected to highpass output.
-    Integrator* const hpIntegrator;
+    FilterModelConfig& fmc;
 
-    /// VCR + associated capacitor connected to bandpass output.
-    Integrator* const bpIntegrator;
-
-private:
     /// Current filter/voice mixer setting.
-    unsigned short* currentMixer;
+    unsigned short* currentMixer = nullptr;
 
     /// Filter input summer setting.
-    unsigned short* currentSummer;
+    unsigned short* currentSummer = nullptr;
 
     /// Filter resonance value.
-    unsigned short* currentResonance;
+    unsigned short* currentResonance = nullptr;
 
     /// Current volume amplifier setting.
-    unsigned short* currentVolume;
+    unsigned short* currentVolume = nullptr;
 
     /// Filter highpass state.
-    int Vhp;
+    int Vhp = 0;
 
     /// Filter bandpass state.
-    int Vbp;
+    int Vbp = 0;
 
     /// Filter lowpass state.
-    int Vlp;
+    int Vlp = 0;
 
     /// Filter external input.
-    int Ve;
+    int Ve = 0;
 
     /// Filter cutoff frequency.
-    unsigned int fc;
+    unsigned int fc = 0;
 
     /// Routing to filter or outside filter
-    bool filt1, filt2, filt3, filtE;
+    //@{
+    bool filt1 = false;
+    bool filt2 = false;
+    bool filt3 = false;
+    bool filtE = false;
+    //@}
 
     /// Switch voice 3 off.
-    bool voice3off;
+    bool voice3off = false;
 
     /// Highpass, bandpass, and lowpass filter modes.
-    bool hp, bp, lp;
+    //@{
+    bool hp = false;
+    bool bp = false;
+    bool lp = false;
+    //@}
 
+private:
     /// Current volume.
-    unsigned char vol;
+    unsigned char vol = 0;
 
     /// Filter enabled.
-    bool enabled;
+    bool enabled = true;
 
     /// Selects which inputs to route through filter.
-    unsigned char filt;
+    unsigned char filt = 0;
 
 protected:
     /**
@@ -122,9 +123,9 @@ protected:
     unsigned int getFC() const { return fc; }
 
 public:
-    Filter(FilterModelConfig* fmc);
+    Filter(FilterModelConfig& fmc);
 
-    virtual ~Filter();
+    virtual ~Filter() = default;
 
     /**
      * SID clocking - 1 cycle
@@ -134,7 +135,7 @@ public:
      * @param v3 voice 3 in
      * @return filtered output
      */
-    unsigned short clock(float v1, float v2, float v3);
+    virtual unsigned short clock(float v1, float v2, float v3) = 0;
 
     /**
      * Enable filter.
@@ -181,47 +182,9 @@ public:
      *
      * @param input a signed 16 bit sample
      */
-    void input(int input) { Ve = fmc->getNormalizedVoice(input/65536.f); }
+    void input(int input) { Ve = fmc.getNormalizedVoice(input/65536.f); }
 };
 
 } // namespace reSIDfp
 
-#if RESID_INLINING || defined(FILTER_CPP)
-
-#include "Integrator.h"
-
-namespace reSIDfp
-{
-
-RESID_INLINE
-unsigned short Filter::clock(float voice1, float voice2, float voice3)
-{
-    const int V1 = fmc->getNormalizedVoice(voice1);
-    const int V2 = fmc->getNormalizedVoice(voice2);
-    // Voice 3 is silenced by voice3off if it is not routed through the filter.
-    const int V3 = (filt3 || !voice3off) ? fmc->getNormalizedVoice(voice3) : 0;
-
-    int Vsum = 0;
-    int Vmix = 0;
-
-    (filt1 ? Vsum : Vmix) += V1;
-    (filt2 ? Vsum : Vmix) += V2;
-    (filt3 ? Vsum : Vmix) += V3;
-    (filtE ? Vsum : Vmix) += Ve;
-
-    Vhp = currentSummer[currentResonance[Vbp] + Vlp + Vsum];
-    Vbp = hpIntegrator->solve(Vhp);
-    Vlp = bpIntegrator->solve(Vbp);
-
-    if (lp) Vmix += Vlp;
-    if (bp) Vmix += Vbp;
-    if (hp) Vmix += Vhp;
-
-    return currentVolume[currentMixer[Vmix]];
-}
-
-} // namespace reSIDfp
-
-#endif
-
 #endif
